@@ -70,14 +70,10 @@ jitoptimize_ode <- function (de,prob){
   mtk <- julia_pkg_import("ModelingToolkit",functions)
 
   odesys = mtk$modelingtoolkitize(prob)
-  odesys = mtk$complete(odesys)
   
   JuliaCall::julia_assign("odesys", odesys)
-  jul_f = JuliaCall::julia_eval("jitf = ODEFunction(odesys,jac=true)")
-  JuliaCall::julia_assign("u0", prob$u0)
-  JuliaCall::julia_assign("p", prob$p)
   JuliaCall::julia_assign("tspan", prob$tspan)
-  new_prob <- JuliaCall::julia_eval("ODEProblem(jitf, u0, tspan, p)")
+  new_prob <- JuliaCall::julia_eval("ODEProblem(complete(odesys, split=false), [], tspan; jac=true)")
 }
 
 #' Jit Optimize an SDEProblem
@@ -106,13 +102,9 @@ jitoptimize_sde <- function (de,prob){
   mtk <- julia_pkg_import("ModelingToolkit",functions)
 
   sdesys = mtk$modelingtoolkitize(prob)
-  sdesys = mtk$complete(sdesys)
   JuliaCall::julia_assign("sdesys", sdesys)
-  jul_f = JuliaCall::julia_eval("jitf = SDEFunction(sdesys,jac=true)")
-  JuliaCall::julia_assign("u0", prob$u0)
-  JuliaCall::julia_assign("p", prob$p)
   JuliaCall::julia_assign("tspan", prob$tspan)
-  new_prob <- JuliaCall::julia_eval("SDEProblem(jitf, jitf.g, u0, tspan, p)")
+  new_prob <- JuliaCall::julia_eval("SDEProblem(complete(sdesys, split=false), [], tspan; jac=true)")
 }
 
 #' Setup DiffEqGPU
